@@ -19,22 +19,13 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 #  Boston, MA 02110-1301, USA.
 
-from gi.repository import GObject, Gedit
+import gi
+gi.require_version('Gedit', '3.0')
+gi.require_version('Gtk', '3.0')
+gi.require_version('PangoCairo', '1.0')
 
+from .appactivatable import MultiEditAppActivatable
 from .viewactivatable import MultiEditViewActivatable
 from .windowactivatable import MultiEditWindowActivatable
 
-class MultiEditAppActivatable(GObject.Object, Gedit.AppActivatable):
-
-    app = GObject.property(type=Gedit.App)
-
-    def __init__(self):
-        GObject.Object.__init__(self)
-
-    def do_activate(self):
-        self.app.add_accelerator("<Primary><Shift>C", "win.multiedit", None)
-
-    def do_deactivate(self):
-        self.app.remove_accelerator("win.multiedit", None)
-
 # ex:ts=4:et:
